import 'package:get_it/get_it.dart';

import '../data/hash/hash_utils.dart';
import '../data/hash/md5_hash.dart';
import '../data/random/mersenne_twister.dart';
import '../data/random/random_utils.dart';
import '../data/result/excel_result.dart';
import '../data/result/result_utils.dart';
import '../data/save_state/json_state.dart';
import '../data/save_state/save_state_utils.dart';
import '../data/winners/isar_winners.dart';
import '../data/winners/winners_utils.dart';

class ServiceLocator {
  ServiceLocator._();
  static final instance = ServiceLocator._();

  final _locator = GetIt.instance;

  HashUtils get hashUtils => _locator<HashUtils>();
  RandomUtils get ramdomUtils => _locator<RandomUtils>();
  WinnersUtils get winnersUtils => _locator<WinnersUtils>();
  SaveStateUtils get saveStateUtils => _locator<SaveStateUtils>();
  ResultUtils get resultUtils => _locator<ResultUtils>();

  Future<void> init() async {
    _locator.registerSingleton<HashUtils>(MD5Hash());
    _locator.registerSingleton<RandomUtils>(
        MersenneTwister(DateTime.now().millisecond));

    IsarWinners isarResult = IsarWinners();
    await isarResult.openDB();
    _locator.registerSingleton<WinnersUtils>(isarResult);
    _locator.registerSingleton<SaveStateUtils>(
        JsonStateSave(winnersUtils: _locator<WinnersUtils>()));

    _locator.registerSingleton<ResultUtils>(ExcelResult());
  }
}
