import 'dart:convert';
import 'dart:io';

import 'package:crypto/crypto.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import '../../common/logger.dart';
import 'hash_utils.dart';

class MD5Hash implements HashUtils {
  @override
  Future<String> getHashFromFile(String filePath) async {
    Hash hasher = md5;
    var input = File(filePath);

    if (!input.existsSync()) {
      logger.e('File "$filePath" does not exist');
      throw FileSystemException("Файл $filePath не найден");
    }

    var value = await hasher.bind(input.openRead()).first;
    debugPrint(value.toString());
    return value.toString();
  }

  @override
  Future<String> getHashFromAsset(String assetName) async {
    final data = await rootBundle.load(assetName);
    final bytes = data.buffer.asUint8List();
    final hash = md5.convert(bytes).toString();
    return hash;
  }

  @override
  String getHashFromData(String data) {
    final bytes = utf8.encode(data);
    final hash = md5.convert(bytes).toString();
    return hash;
  }
}
