import 'package:quiz/data/random/random_utils.dart';

class MersenneTwister implements RandomUtils {
  static const _n = 624;
  static const _m = 397;
  static const _matrixA = 0x9908b0df;
  static const _upperMask = 0x80000000;
  static const _lowerMask = 0x7fffffff;

  final List<int> _mt = List.filled(_n, 0);
  int _index = _n + 1;

  MersenneTwister(int seed) {
    _mt[0] = seed;
    for (var i = 1; i < _n; i++) {
      _mt[i] = (_mt[i - 1] ^ (_mt[i - 1] >> 30)) + 0x6c078965;
      _mt[i] &= 0xffffffff;
    }
  }

  @override
  List<int> generateIntNumbers(int count, int min, int max) {
    List<int> result = [];
    for (var i = 0; i < count; i++) {
      result.add(min + (_nextInt32() % (max - min)));
    }
    return result;
  }

  @override
  int nextInt(int min, int max) {
    if (min >= max) {
      throw ArgumentError("min must be less than max");
    }
    return min + (_nextInt32() % (max - min));
  }

  @override
  double nextDouble() {
    return _nextInt32() / 0x100000000;
  }

  int _nextInt32() {
    if (_index >= _n) {
      _twist();
    }

    var y = _mt[_index++];
    y ^= (y >> 11);
    y ^= ((y << 7) & 0x9d2c5680);
    y ^= ((y << 15) & 0xefc60000);
    y ^= (y >> 18);

    return y;
  }

  void _twist() {
    for (var i = 0; i < _n; i++) {
      var upperBits = _mt[i] & _upperMask;
      var lowerBits = _mt[(i + 1) % _n] & _lowerMask;
      var x = upperBits | lowerBits;
      var xA =
          (x >> 1) ^ ((_mt[(i + _m) % _n]) | ((x & 1) == 0 ? 0 : _matrixA));
      _mt[i] = _mt[(_n + i + 1) % _n] ^ xA;
    }
    _index = 0;
  }
}
