import 'dart:io';

import 'package:excel/excel.dart';
import 'package:flutter/foundation.dart';
import 'package:intl/intl.dart';

import '../../common/file_names.dart';
import '../../common/logger.dart';
import '../../common/service_locator.dart';
import 'result_utils.dart';

class ExcelResult implements ResultUtils {
  @override
  void saveResult(String selectedFolder) {
    var excel = Excel.createExcel();

    Sheet sheetObject = excel['Результаты'];

    sheetObject.setColumnWidth(0, 14);
    sheetObject.setColumnWidth(1, 21);
    sheetObject.setColumnWidth(2, 23);

    sheetObject.merge(
        CellIndex.indexByString("A1"), CellIndex.indexByString("C1"),
        customValue: TextCellValue(
            "Дата и время выгрузки: ${DateFormat('yyyy.MM.dd HH:mm:ss').format(DateTime.now())}"));

    const Map<String, String> headers = {
      'A2': 'Участник',
      'B2': 'Подарок',
      'C2': 'Время',
    };

    // Заполняем данные
    int rowIndex = 3;
    final listRes = ServiceLocator.instance.winnersUtils.getAllDataInList();
    for (var obj in listRes) {
      sheetObject.cell(CellIndex.indexByString("A$rowIndex")).value =
          TextCellValue(obj[0]);
      sheetObject.cell(CellIndex.indexByString("B$rowIndex")).value =
          TextCellValue(obj[1]);
      sheetObject.cell(CellIndex.indexByString("C$rowIndex")).value =
          TextCellValue(obj[2]);
      rowIndex++;
    }

    var lastRow = sheetObject.maxRows;
    var lastColumn = headers.length;
    for (var i = 1; i < lastRow; i++) {
      for (var j = 0; j < lastColumn; j++) {
        sheetObject
            .cell(CellIndex.indexByColumnRow(rowIndex: i, columnIndex: j))
            .cellStyle = CellStyle(
          topBorder: Border(
            borderColorHex: ExcelColor.black,
            borderStyle: BorderStyle.Thin,
          ),
          bottomBorder: Border(
            borderColorHex: ExcelColor.black,
            borderStyle: BorderStyle.Thin,
          ),
          leftBorder: Border(
            borderColorHex: ExcelColor.black,
            borderStyle: BorderStyle.Thin,
          ),
          rightBorder: Border(
            borderColorHex: ExcelColor.black,
            borderStyle: BorderStyle.Thin,
          ),
        );
      }
    }

    // Заполняем заголовки
    headers.forEach((key, value) {
      sheetObject.cell(CellIndex.indexByString(key))
        ..value = TextCellValue(value)
        ..cellStyle = CellStyle(
            bold: true,
            backgroundColorHex: ExcelColor.fromHexString('#4286f5'),
            fontColorHex: ExcelColor.white);
    });

    excel.delete('Sheet1');

    try {
      final String currentDirectory = Directory.current.path;
      final devDirectory = '$currentDirectory\\${FileNames.devDir}';
      if (!Directory(devDirectory).existsSync()) {
        Directory(devDirectory).createSync();
      }

      if (!File(FileNames.devResultPath).existsSync()) {
        final file = File(FileNames.devResultPath);
        // Сохраняем файл Excel
        List<int>? fileBytes = excel.save();
        if (fileBytes != null) {
          file
            ..createSync(recursive: true)
            ..writeAsBytesSync(fileBytes);
        }
      }
      debugPrint('Файл сохранен успешно');
      copyResult(selectedFolder);
    } catch (e) {
      logger.e('Произошла ошибка при сохранении файла: $e');
      throw Exception('Произошла ошибка при сохранении файла');
    }
  }

  @override
  void copyResult(String selectedFolder) {
    final filePath = '$selectedFolder\\${FileNames.resultName}';
    try {
      File(FileNames.devResultPath).copySync(filePath);
      debugPrint('Файл скопирован успешно в папке: $selectedFolder');
    } catch (e) {
      logger.e('Произошла ошибка при сохранении файла: $e');
      throw Exception('Произошла ошибка при сохранении файла');
    }
  }
}
