import 'dart:convert';
import 'dart:io';

import 'package:flutter/foundation.dart';

import '../../common/file_names.dart';
import '../../domain/models/global_state.dart';
import '../winners/winners_utils.dart';
import 'save_state_utils.dart';

class JsonStateSave implements SaveStateUtils {
  final WinnersUtils winnersUtils;
  JsonStateSave({required this.winnersUtils});
  @override
  Future<void> cleanAll() async {
    var devStateFile = File(FileNames.devStatePath);
    if (devStateFile.existsSync()) {
      await devStateFile.delete();
    }

    var devResultFile = File(FileNames.devResultPath);
    if (devResultFile.existsSync()) {
      await devResultFile.delete();
    }

    var origFile = File(FileNames.origPartCopyPath);
    if (origFile.existsSync()) {
      await origFile.delete();
    }

    var devLastFile = File(FileNames.devLastPath);
    if (devLastFile.existsSync()) {
      await devLastFile.writeAsString('');
    }

    winnersUtils.cleanAllDB();
  }

  @override
  GlobalState getState() {
    final String currentDirectory = Directory.current.path;
    final devDirectory = '$currentDirectory\\${FileNames.devDir}';
    if (!Directory(devDirectory).existsSync()) {
      // winnersUtils.cleanAllDB();
      Directory(devDirectory).createSync();
    }

    if (FileSystemEntity.typeSync(FileNames.devStatePath) ==
        FileSystemEntityType.notFound) {
      final state =
          GlobalState(flatRest: List.filled(45, true, growable: true));
      File(FileNames.devStatePath)
          .writeAsStringSync(jsonEncode(state.toJson()));
      return state;
    } else {
      var jsonString = File(FileNames.devStatePath).readAsStringSync();
      var json = jsonDecode(jsonString);
      var myObject = GlobalState.fromJson(json);
      debugPrint(myObject.toString());
      return myObject;
    }
  }

  @override
  void rewriteState(GlobalState state) {
    File(FileNames.devStatePath).writeAsStringSync(jsonEncode(state.toJson()));
  }
}
