import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:intl/intl.dart';
import 'package:isar/isar.dart';

import '../../common/file_names.dart';
import '../../domain/models/present.dart';
import '../../domain/models/win_string.dart';
import 'winners_utils.dart';

class IsarWinners implements WinnersUtils {
  late Isar db;

  Future<void> openDB() async {
    if (Isar.instanceNames.isEmpty) {
      final String currentDirectory = Directory.current.path;
      final devDirectory = '$currentDirectory\\${FileNames.devDir}';
      if (!Directory(devDirectory).existsSync()) {
        Directory(devDirectory).createSync();
      }
      db = await Isar.open(
        [WinStringSchema],
        inspector: true,
        directory: Directory(devDirectory).path,
      );
    }

    db = await Future.value(Isar.getInstance());
  }

  @override
  void writeParticipart(String number) {
    final item = WinString()..participant = number;
    db.writeTxnSync(() => db.winStrings.putSync(item));
  }

  @override
  void writePhoneString(String number) {
    final item = WinString()
      ..participant = number
      ..present = Present.phone.name
      ..dateTime = DateFormat('yyyy.MM.dd HH:mm:ss').format(DateTime.now());
    db.writeTxnSync(() => db.winStrings.putSync(item));
  }

  @override
  void writePresent(String present) {
    // to do handle error
    final curPart = db.winStrings.filter().presentIsNull().findFirstSync();
    if (curPart != null) {
      curPart.present = present;
      curPart.dateTime =
          DateFormat('yyyy.MM.dd HH:mm:ss').format(DateTime.now());

      db.writeTxnSync(() async {
        db.winStrings.putSync(curPart);
      });
    }
  }

  @override
  List<List<String>> getAllDataInList() {
    final wins = db.winStrings.where().findAllSync();
    return wins
        .map((winString) => [
              winString.participant,
              winString.present ?? 'null',
              winString.dateTime ?? 'null',
            ])
        .toList();
  }

  @override
  void cleanAllDB() {
    db.writeTxnSync(() => db.clearSync());
  }

  @override
  List<WinString> getWinsPhone() {
    final wins =
        db.winStrings.filter().presentEqualTo(Present.phone.name).findAllSync();
    debugPrint(wins.length.toString());
    return wins;
  }

  @override
  List<WinString> getLastWins() {
    final wins =
        db.winStrings.where().filter().presentIsNotNull().findAllSync();
    final lasts = wins.length < 6 ? wins : wins.sublist(wins.length - 5);
    debugPrint(lasts.length.toString());
//-----------------------------------------------------------------------------------
    var lastFile = File(FileNames.devLastPath);
    if (lastFile.existsSync()) {
      lastFile.createSync();
    }
    final String forTv = lasts
        .map((e) {
          String image = '';
          if (e.present != null && e.present!.contains(Present.flat.name)) {
            image = 'D:\\priz\\apart.png';
          } else if (e.present == Present.moto.name) {
            image = 'D:\\priz\\byke.png';
          } else if (e.present == Present.avto.name) {
            image = 'D:\\priz\\car.png';
          }
          return '${e.participant},$image';
        })
        .toList()
        .reversed
        .join('\n');
    lastFile.writeAsStringSync(forTv);
//-----------------------------------------------------------------------------------
    return lasts;
  }

  @override
  List<String> getAllWinsNumber() {
    final wins = db.winStrings.where().findAllSync();
    return wins
        .map(
          (winString) => winString.participant,
        )
        .toList();
  }
}
