import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';

import '../../common/theme/app_colors.dart';
import '../controllers/app_state_notifier.dart';
import '../quiz_view/phones_screen.dart';
import '../quiz_view/quiz_screen.dart';
import '../result_view/result_screen.dart';
import '../settings_view/settings_screen.dart';
import 'widgets/background.dart';
import 'widgets/footer.dart';
import 'widgets/req_app_bar.dart';

class BaseScreen extends ConsumerWidget {
  const BaseScreen({super.key});

  List<Widget> get body => [
        const SettingsScreen(),
        const QuizScreen(),
        const PhonesScreen(),
        const ResultScreen(),
      ];

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    debugPrint('build BaseScreen');
    final currentTab = ref.watch(appStateNotifierProvider).currentTab;

    return Scaffold(
      backgroundColor: AppColors.blueBackground,
      body: TweenAnimationBuilder<double>(
          key: ValueKey(currentTab),
          tween: Tween<double>(begin: 0.0, end: 1.0),
          curve: Curves.ease,
          duration: const Duration(milliseconds: 1000),
          builder: (BuildContext context, double opacity, Widget? child) {
            return Opacity(
              opacity: opacity,
              child: Stack(
                fit: StackFit.expand,
                children: [
                  const BackGround(),
                  Column(
                    children: [
                      const ReqAppBar(),
                      Expanded(child: body[currentTab.step]),
                      const Footer(),
                    ],
                  ),
                ],
              ),
            );
          }),
    );
  }
}
