import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../../../common/theme/app_colors.dart';
import '../../../common/theme/app_text_style.dart';
import '../../../domain/models/app_tabs.dart';
import '../../controllers/app_state_notifier.dart';

class TabsRow extends ConsumerWidget {
  const TabsRow({super.key});

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    ScreenUtil.init(context, designSize: const Size(1280, 720));
    final currentTabIndex =
        switch (ref.watch(appStateNotifierProvider).currentTab) {
      AppTabs.settings => 0,
      AppTabs.quiz => 1,
      AppTabs.phones => 1,
      AppTabs.result => 2,
    };
    return SizedBox(
      height: 28.h,
      child: ListView.separated(
          scrollDirection: Axis.horizontal,
          shrinkWrap: true,
          physics: const NeverScrollableScrollPhysics(),
          itemBuilder: (context, index) {
            final textTab = switch (index) {
              0 => AppTabs.settings.name,
              1 => 'Выбор подарков',
              2 => AppTabs.result.name,
              int() => '',
            };
            return index == currentTabIndex
                ? SelectedTab(
                    text: textTab,
                  )
                : UnSelectedTab(text: textTab);
          },
          separatorBuilder: (context, index) => SizedBox(width: 4.w),
          itemCount: 3),
    );
  }
}

class SelectedTab extends StatelessWidget {
  const SelectedTab({
    super.key,
    required this.text,
  });
  final String text;

  @override
  Widget build(BuildContext context) {
    ScreenUtil.init(context, designSize: const Size(1280, 720));
    return Container(
      alignment: Alignment.center,
      padding: EdgeInsets.symmetric(horizontal: 12.w, vertical: 4.h),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(20.r),
        color: AppColors.blueTabDark,
      ),
      child: Text(
        text,
        style: Montserrat().size11Weihtg600,
      ),
    );
  }
}

class UnSelectedTab extends StatelessWidget {
  const UnSelectedTab({
    super.key,
    required this.text,
  });
  final String text;

  @override
  Widget build(BuildContext context) {
    ScreenUtil.init(context, designSize: const Size(1280, 720));
    return Container(
      alignment: Alignment.center,
      padding: EdgeInsets.symmetric(horizontal: 12.w, vertical: 4.h),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(20.r),
        border: Border.all(color: AppColors.textUnselected, width: 1.h),
      ),
      child: Text(
        text,
        style: Montserrat()
            .size11Weihtg600
            .copyWith(color: AppColors.textUnselected),
      ),
    );
  }
}
