import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:intl/intl.dart';

import '../../common/images.dart';
import '../../common/theme/app_text_style.dart';

class CurrentTime extends StatefulWidget {
  const CurrentTime({
    super.key,
    this.isBig = false,
  });

  final bool isBig;

  @override
  State<CurrentTime> createState() => _CurrentTimeState();
}

class _CurrentTimeState extends State<CurrentTime> {
  late Timer _timer;
  late DateTime _currentTime;
  @override
  void initState() {
    super.initState();
    _currentTime = DateTime.now();
    _timer = Timer.periodic(const Duration(seconds: 1), (timer) {
      setState(() {
        _currentTime = DateTime.now();
      });
    });
  }

  @override
  void dispose() {
    _timer.cancel();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    ScreenUtil.init(context, designSize: const Size(1280, 720));

    return Row(
      mainAxisSize: MainAxisSize.min,
      children: [
        Text(
          DateFormat('dd.MM.yyyy').format(_currentTime),
          style: widget.isBig ? Sans().size18Weihtg500 : Sans().size16Weihtg500,
        ),
        SizedBox(width: 10.5.w),
        SvgPicture.asset(
          AppIcons.clock,
          width: widget.isBig ? 20.w : 18.w,
          height: widget.isBig ? 20.w : 18.w,
        ),
        SizedBox(width: 10.5.w),
        Text(
          DateFormat('HH : mm : ss').format(_currentTime),
          style: widget.isBig ? Sans().size18Weihtg500 : Sans().size16Weihtg500,
        ),
      ],
    );
  }
}
