import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../../common/theme/app_colors.dart';
import '../../common/theme/app_text_style.dart';

class ElevButton extends StatelessWidget {
  const ElevButton({
    super.key,
    required this.child,
    this.callback,
    this.horizontalPadding,
  });
  final Widget child;
  final Function()? callback;
  final double? horizontalPadding;

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      onPressed: callback,
      style: ButtonStyle(
        textStyle: MaterialStateProperty.all<TextStyle>(
          Montserrat().size18Weihtg600,
        ),
        backgroundColor: MaterialStateProperty.resolveWith<Color>(
            (Set<MaterialState> states) {
          if (states.contains(MaterialState.disabled)) {
            return AppColors.white.withOpacity(0.2);
          } else if (states.contains(MaterialState.pressed)) {
            return AppColors.blueButton;
          }
          return AppColors.pink;
        }),
        foregroundColor: MaterialStateProperty.resolveWith<Color>(
            (Set<MaterialState> states) {
          if (states.contains(MaterialState.disabled)) {
            return AppColors.white.withOpacity(0.4);
          }
          return AppColors.white;
        }),
        shape: MaterialStateProperty.all<RoundedRectangleBorder>(
          RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(16.r),
          ),
        ),
        overlayColor: MaterialStateProperty.resolveWith<Color?>(
            (Set<MaterialState> states) {
          if (states.contains(MaterialState.pressed)) {
            return AppColors.blueButton;
          } else if (states.contains(MaterialState.hovered)) {
            return AppColors.pink;
          }
          return null;
        }),
        padding: MaterialStateProperty.all<EdgeInsetsGeometry>(
            EdgeInsets.symmetric(
                horizontal:
                    horizontalPadding == null ? 40.w : horizontalPadding!.w)),
        fixedSize: MaterialStateProperty.all<Size>(Size.fromHeight(64.h)),
        elevation: MaterialStateProperty.resolveWith<double>(
            (Set<MaterialState> states) {
          if (states.contains(MaterialState.disabled)) {
            return 0;
          } else if (states.contains(MaterialState.hovered)) {
            return 4.h;
          } else if (states.contains(MaterialState.pressed)) {
            return 8.h;
          }
          return 2.h;
        }),
        shadowColor: MaterialStateProperty.resolveWith<Color?>(
            (Set<MaterialState> states) {
          if (states.contains(MaterialState.hovered) ||
              states.contains(MaterialState.pressed)) {
            return AppColors.sea;
          }
          return null;
        }),
      ),
      child: child,
    );
  }
}
