import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';

import '../../common/service_locator.dart';
import '../../domain/models/app_state.dart';
import '../../domain/models/app_tabs.dart';
import '../../domain/models/present.dart';
import 'global.dart';

part 'app_state_notifier.g.dart';

@riverpod
class AppStateNotifier extends _$AppStateNotifier {
  @override
  AppState build() {
    getExeHash();
    return AppState(
      currentTab: ref.read(globalProvider).currentStep,
      avtoCount: ref.read(globalProvider).avtoCount,
      motoCount: ref.read(globalProvider).motoCount,
      flatCount: ref.read(globalProvider).flatCount,
      phoneCount: ref.read(globalProvider).phoneCount,
    );
  }

  Future<void> getExeHash() async {
    debugPrint(kReleaseMode.toString());
    final dir = Directory.current.path;
    var filePath = dir +
        (kReleaseMode
            ? ('/${Platform.executable}')
            : '/build/windows/x64/runner/Debug/quiz.exe');

    final exeHash =
        await ServiceLocator.instance.hashUtils.getHashFromFile(filePath);
    state = state.copyWith(exeHash: exeHash);
  }

  void changeTab(AppTabs tab) {
    state = state.copyWith(currentTab: tab);
    ref.read(globalProvider.notifier).changeTab(tab);
  }

  void startedGeneretePhone() {
    state = state.copyWith(startGeneratePhone: true);
  }

  void changePresentCount(Present present, String countString) {
    ref.read(globalProvider.notifier).changePresentCount(present, countString);
    switch (present) {
      case Present.flat:
        state = state.copyWith(flatCount: int.tryParse(countString) ?? 0);
        break;
      case Present.avto:
        state = state.copyWith(avtoCount: int.tryParse(countString) ?? 0);
        break;
      case Present.moto:
        state = state.copyWith(motoCount: int.tryParse(countString) ?? 0);
        break;
      case Present.phone:
        state = state.copyWith(phoneCount: int.tryParse(countString) ?? 0);
        break;
      default:
    }
  }
}
