import 'package:riverpod_annotation/riverpod_annotation.dart';

import '../../common/service_locator.dart';
import '../../domain/models/app_tabs.dart';
import '../../domain/models/global_state.dart';
import '../../domain/models/present.dart';

part 'global.g.dart';

@Riverpod(keepAlive: true)
class Global extends _$Global {
  @override
  GlobalState build() {
    return ServiceLocator.instance.saveStateUtils.getState();
  }

  void partLoaded() {
    state = state.copyWith(participantsLoaded: true);
    ServiceLocator.instance.saveStateUtils.rewriteState(state);
  }

  void startCheckCount() {
    state = state.copyWith(startCheckCount: true);
    ServiceLocator.instance.saveStateUtils.rewriteState(state);
  }

  void changeTab(AppTabs tab) {
    state = state.copyWith(currentStep: tab);
    ServiceLocator.instance.saveStateUtils.rewriteState(state);
  }

  void changePresentCount(Present present, String countString) {
    switch (present) {
      case Present.flat:
        final count = int.tryParse(countString) ?? 0;
        state = state.copyWith(
            flatCount: count,
            flatRest: List.filled(count, true, growable: true));
        break;
      case Present.avto:
        state = state.copyWith(avtoCount: int.tryParse(countString) ?? 0);
        break;
      case Present.moto:
        state = state.copyWith(motoCount: int.tryParse(countString) ?? 0);
        break;
      case Present.phone:
        state = state.copyWith(phoneCount: int.tryParse(countString) ?? 0);
        break;
      default:
    }
    ServiceLocator.instance.saveStateUtils.rewriteState(state);
  }

  void avtoSelect() {
    state =
        state.copyWith(currentPresent: Present.avto, currentFlatNumber: null);
    ServiceLocator.instance.saveStateUtils.rewriteState(state);
  }

  void motoSelect() {
    state =
        state.copyWith(currentPresent: Present.moto, currentFlatNumber: null);
    ServiceLocator.instance.saveStateUtils.rewriteState(state);
  }

  void flatSelect() {
    state = state.copyWith(currentPresent: Present.flat);
    ServiceLocator.instance.saveStateUtils.rewriteState(state);
  }

  void flatNumberSelect(int number) {
    state =
        state.copyWith(currentPresent: Present.flat, currentFlatNumber: number);
    ServiceLocator.instance.saveStateUtils.rewriteState(state);
  }

  void avtoSet(int count) {
    state = state.copyWith(avtoCount: count, currentPresent: null);
    ServiceLocator.instance.saveStateUtils.rewriteState(state);
  }

  void motoSet(int count) {
    state = state.copyWith(motoCount: count, currentPresent: null);
    ServiceLocator.instance.saveStateUtils.rewriteState(state);
  }

  void flatSet(List<bool> newList) {
    state = state.copyWith(
        flatRest: newList, currentPresent: null, currentFlatNumber: null);
    ServiceLocator.instance.saveStateUtils.rewriteState(state);
  }

  void partNumberSet(String number) {
    state = state.copyWith(currentNumber: number);
    ServiceLocator.instance.saveStateUtils.rewriteState(state);
  }

  void addPhone(int i) {
    state = state.copyWith(currentPhone: i);
    ServiceLocator.instance.saveStateUtils.rewriteState(state);
  }
}
