import 'package:riverpod_annotation/riverpod_annotation.dart';

import '../../common/service_locator.dart';
import '../../domain/models/present.dart';
import '../../domain/models/quiz_state.dart';
import 'global.dart';
import 'participants_list_notifier.dart';

part 'quiz_notifier.g.dart';

@riverpod
class QuizNotifier extends _$QuizNotifier {
  @override
  QuizState build() {
    return QuizState(
      flatRest: ref.read(globalProvider).flatRest,
      avtoRest: ref.read(globalProvider).avtoCount,
      motoRest: ref.read(globalProvider).motoCount,
      currentFlatNumber: ref.read(globalProvider).currentFlatNumber,
      currentNumber: ref.read(globalProvider).currentNumber,
      currentPresent: ref.read(globalProvider).currentPresent,
      lastWins: ServiceLocator.instance.winnersUtils.getLastWins(),
    );
  }

  bool get isComplete {
    final bool flat =
        state.flatRest.toSet().length == 1 && !state.flatRest.toSet().first;
    return flat && state.motoRest <= 0 && state.avtoRest <= 0;
  }

  int get presentRest =>
      state.avtoRest +
      state.motoRest +
      state.flatRest.where((element) => element).length;

  int get flatResrCount => state.flatRest.where((element) => element).length;

  void getLast() {
    state = state.copyWith(
        lastWins: ServiceLocator.instance.winnersUtils.getLastWins());
  }

  void avtoSelect() {
    state =
        state.copyWith(currentPresent: Present.avto, currentFlatNumber: null);
    ref.read(globalProvider.notifier).avtoSelect();
  }

  void motoSelect() {
    state =
        state.copyWith(currentPresent: Present.moto, currentFlatNumber: null);
    ref.read(globalProvider.notifier).motoSelect();
  }

  void flatSelect() {
    state = state.copyWith(currentPresent: Present.flat);
    ref.read(globalProvider.notifier).flatSelect();
    if (flatResrCount == 1) {
      int lastFlat = state.flatRest.indexWhere((element) => element);
      flatNumberSelect(lastFlat);
    }
  }

  void flatNumberSelect(int number) {
    state =
        state.copyWith(currentPresent: Present.flat, currentFlatNumber: number);
    ref.read(globalProvider.notifier).flatNumberSelect(number);
  }

  void avtoSet() {
    ServiceLocator.instance.winnersUtils
        .writePresent(state.currentPresent!.name);
    final count = state.avtoRest - 1;
    state = state.copyWith(avtoRest: count, currentPresent: null);
    ref.read(globalProvider.notifier).avtoSet(count);
    getLast();
  }

  void motoSet() {
    ServiceLocator.instance.winnersUtils
        .writePresent(state.currentPresent!.name);
    final count = state.motoRest - 1;
    state = state.copyWith(motoRest: count, currentPresent: null);
    ref.read(globalProvider.notifier).motoSet(count);
    getLast();
  }

  void flatSet() {
    List<bool> newList = List.from(state.flatRest);
    int number = state.currentFlatNumber ?? 0;
    newList[number] = false;
    ServiceLocator.instance.winnersUtils
        .writePresent('${state.currentPresent!.name} ${number + 1}');
    state = state.copyWith(
        flatRest: newList, currentPresent: null, currentFlatNumber: null);
    ref.read(globalProvider.notifier).flatSet(newList);
    getLast();
  }

  void setPresentPartic() {
    switch (state.currentPresent) {
      case Present.avto:
        avtoSet();
        break;
      case Present.moto:
        motoSet();
        break;
      case Present.flat:
        flatSet();
        break;
      default:
        break;
    }
  }

  void getNumber() {
    if (state.currentPresent != null) {
      setPresentPartic();
    }
    int index = ServiceLocator.instance.ramdomUtils
        .nextInt(0, ref.read(participantsListNotifierProvider).length);
    String number = ref.read(participantsListNotifierProvider)[index];
    state = state.copyWith(currentNumber: number, currentPresent: null);
    ServiceLocator.instance.winnersUtils.writeParticipart(number);
    ref
        .read(participantsListNotifierProvider.notifier)
        .removeParticipant(index);
    ref.read(globalProvider.notifier).partNumberSet(number);
  }
}
