import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_svg/flutter_svg.dart';

import '../../common/images.dart';
import '../../common/service_locator.dart';
import '../../common/theme/app_colors.dart';
import '../controllers/app_state_notifier.dart';
import '../controllers/global.dart';
import '../controllers/participants_list_notifier.dart';
import 'widgets/phone_win.dart';
import 'widgets/select_phones_view.dart';

class PhonesScreen extends ConsumerStatefulWidget {
  const PhonesScreen({super.key});

  @override
  ConsumerState<PhonesScreen> createState() => _PhonesScreenState();
}

class _PhonesScreenState extends ConsumerState<PhonesScreen>
    with SingleTickerProviderStateMixin {
  List<String> _numbers = [];
  final ScrollController _scrollController = ScrollController();
  bool startGenerate = false;
  final duration = const Duration(milliseconds: 250);
  bool visible = false;

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance.addPostFrameCallback((_) {
      _numbers = ServiceLocator.instance.winnersUtils
          .getWinsPhone()
          .map((e) => e.participant)
          .toList();
      setState(() {});
      startGenerate = _numbers.isNotEmpty;
      if (startGenerate) {
        _loadNumbers();
      }
    });
  }

  @override
  void dispose() {
    _scrollController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    ScreenUtil.init(context, designSize: const Size(1280, 720));

    return Column(
      children: [
        SizedBox(height: 68.h),
        Padding(
          padding: EdgeInsets.symmetric(horizontal: 44.w),
          child: Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              SelectPhonesView(
                startCallBack: () {
                  setState(() {
                    startGenerate = true;
                  });
                  _loadNumbers();
                },
              ),
              ref.watch(globalProvider).currentPhone == 0
                  ? Expanded(
                      child: SvgPicture.asset(
                        AppImages.phones,
                        width: 605.w,
                        height: 440.h,
                      ),
                    )
                  : Row(
                      children: [
                        SizedBox(width: 32.w),
                        SizedBox(
                          width: 760.w,
                          height: 526.h,
                          child: RawScrollbar(
                            controller: _scrollController,
                            interactive: true,
                            thickness: 5.w,
                            shape: RoundedRectangleBorder(
                                borderRadius: BorderRadius.circular(6),
                                side: BorderSide(
                                  color: AppColors.blueScrollbarBorder,
                                  width: 1.w,
                                )),
                            trackVisibility: true,
                            thumbVisibility: true,
                            trackColor: AppColors.blueScrollbarTrack,
                            thumbColor: AppColors.blueScrollbarThumb,
                            trackRadius: Radius.circular(6.r),
                            child: NotificationListener<ScrollNotification>(
                              onNotification: (notification) => true,
                              child: GridView.builder(
                                controller: _scrollController,
                                padding:
                                    EdgeInsets.only(right: 76.w, bottom: 12.h),
                                itemCount: _numbers.length,
                                gridDelegate:
                                    const SliverGridDelegateWithFixedCrossAxisCount(
                                  crossAxisCount: 6,
                                  mainAxisSpacing: 12,
                                  crossAxisSpacing: 12,
                                  childAspectRatio: 2.9,
                                ),
                                itemBuilder: (context, index) {
                                  return PhoneWin(number: _numbers[index]);
                                },
                              ),
                            ),
                          ),
                        ),
                      ],
                    ),
            ],
          ),
        ),
      ],
    );
  }

  int _calculateNumber() {
    return ServiceLocator.instance.ramdomUtils
        .nextInt(0, ref.read(participantsListNotifierProvider).length);
  }

  void _scrollToLastItem() {
    _scrollController.animateTo(
      _scrollController.position.maxScrollExtent,
      duration: const Duration(milliseconds: 250),
      curve: Curves.easeOut,
    );
  }

  Future<void> _loadNumbers() async {
    ref.read(appStateNotifierProvider.notifier).startedGeneretePhone();
    for (var i = ref.read(globalProvider).currentPhone;
        i < ref.read(appStateNotifierProvider).phoneCount;
        i++) {
      if (i > 0) _scrollToLastItem();
      await Future.delayed(duration);
      final newNumber = _calculateNumber();

      setState(() {
        _numbers.add(ref.read(participantsListNotifierProvider)[newNumber]);
      });

      await Future.delayed(Duration.zero);

      ServiceLocator.instance.winnersUtils.writePhoneString(
          ref.read(participantsListNotifierProvider)[newNumber]);
      debugPrint(i.toString());
      await ref
          .read(participantsListNotifierProvider.notifier)
          .removeParticipant(newNumber);
      ref.read(globalProvider.notifier).addPhone(i + 1);

      await Future.delayed(duration);
    }
  }
}
