import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_svg/flutter_svg.dart';

import '../../common/images.dart';
import '../../common/theme/app_text_style.dart';
import '../../domain/models/present.dart';
import '../controllers/quiz_notifier.dart';
import 'widgets/flat_number.dart';
import 'widgets/last_wins_widget.dart';
import 'widgets/participant_view.dart';
import 'widgets/select_present_button.dart';

class QuizScreen extends ConsumerWidget {
  const QuizScreen({super.key});

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    debugPrint('build QuizScreen');
    ScreenUtil.init(context, designSize: const Size(1280, 720));
    final quizState = ref.watch(quizNotifierProvider);
    final Widget image = switch (quizState.currentPresent) {
      Present.avto => SvgPicture.asset(
          AppImages.avto,
          width: 490.w,
          height: 210.h,
        ),
      Present.moto => SvgPicture.asset(
          AppImages.moto,
          width: 467.w,
          height: 274.h,
        ),
      Present.flat => SvgPicture.asset(
          AppImages.flat,
          width: 410.w,
          height: 210.h,
        ),
      Present.phone => SvgPicture.asset(
          AppImages.present,
          width: 355.w,
          height: 371.h,
        ),
      null => SvgPicture.asset(
          AppImages.present,
          width: 355.w,
          height: 371.h,
        ),
    };
    return Padding(
      padding: EdgeInsets.only(left: 41.w),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          SizedBox(height: 68.h),
          SizedBox(
            height: 424.h,
            child: Row(
              children: [
                const ParticipantView(),
                SizedBox(width: 22.w),
                Column(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    SelectPresentButton(
                      callback: quizState.motoRest == 0 ||
                              quizState.currentNumber == null
                          ? null
                          : () {
                              ref
                                  .read(quizNotifierProvider.notifier)
                                  .motoSelect();
                            },
                      present: Present.moto,
                    ),
                    SelectPresentButton(
                      callback: ref
                                      .read(quizNotifierProvider.notifier)
                                      .flatResrCount ==
                                  0 ||
                              quizState.currentNumber == null
                          ? null
                          : () {
                              ref
                                  .read(quizNotifierProvider.notifier)
                                  .flatSelect();
                            },
                      present: Present.flat,
                    ),
                    SelectPresentButton(
                      callback: quizState.avtoRest == 0 ||
                              quizState.currentNumber == null
                          ? null
                          : () {
                              ref
                                  .read(quizNotifierProvider.notifier)
                                  .avtoSelect();
                            },
                      present: Present.avto,
                    ),
                  ],
                ),
                Expanded(
                    child: Column(
                  mainAxisAlignment: quizState.currentPresent == Present.flat
                      ? MainAxisAlignment.spaceBetween
                      : MainAxisAlignment.center,
                  children: [
                    image,
                    if (quizState.currentPresent == Present.flat)
                      SizedBox(
                        width: 467.w,
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            Text(
                              'Квартира №',
                              style: Montserrat().size18Weihtg600,
                            ),
                            Column(
                              mainAxisSize: MainAxisSize.min,
                              children: [
                                SizedBox(height: 11.h),
                                SizedBox(
                                  width: 467.w,
                                  child: GridView.count(
                                    crossAxisCount: 13,
                                    crossAxisSpacing: 4.w,
                                    mainAxisSpacing: 4.w,
                                    shrinkWrap: true,
                                    children: List.generate(
                                      ref
                                          .read(quizNotifierProvider)
                                          .flatRest
                                          .length,
                                      (index) => FlatNumberButton(
                                        number: index,
                                      ),
                                    ),
                                  ),
                                ),
                              ],
                            ),
                          ],
                        ),
                      ),
                  ],
                )),
              ],
            ),
          ),
          if (quizState.lastWins.isNotEmpty) const LastWinsWidget()
        ],
      ),
    );
  }
}
