import 'package:flutter/material.dart';

import '../../../common/theme/app_text_style.dart';

class AnimatedCount extends StatefulWidget {
  final int? count;
  const AnimatedCount({super.key, this.count});

  @override
  AnimatedCountState createState() => AnimatedCountState();
}

class AnimatedCountState extends State<AnimatedCount>
    with SingleTickerProviderStateMixin {
  AnimationController? _controller;
  Animation<int>? _animation;
  String? _displayText;

  @override
  void initState() {
    super.initState();
    _controller = AnimationController(
      duration: const Duration(milliseconds: 600),
      vsync: this,
    );

    _setupAnimation();
  }

  void _setupAnimation() {
    int endValue = widget.count ?? 0;
    _animation = IntTween(begin: 0, end: endValue).animate(
      CurvedAnimation(parent: _controller!, curve: Curves.fastOutSlowIn),
    )..addListener(() {
        setState(() {
          _displayText = widget.count == null || _animation?.value == 0
              ? '0000000'
              : _animation?.value.toString();
        });
      });

    _controller!.forward();
  }

  @override
  void didUpdateWidget(AnimatedCount oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (widget.count != oldWidget.count) {
      _setupAnimation();
      _controller!
        ..reset()
        ..forward();
    }
  }

  @override
  Widget build(BuildContext context) {
    return Text(
      _displayText ?? '0000000',
      style: Sans().size58Weihtg500,
    );
  }

  @override
  void dispose() {
    _controller?.dispose();
    super.dispose();
  }
}
