import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../../../common/theme/app_colors.dart';
import '../../../common/theme/app_text_style.dart';
import '../../controllers/quiz_notifier.dart';

class FlatNumberButton extends ConsumerWidget {
  const FlatNumberButton({
    super.key,
    required this.number,
  });
  final int number;

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final quizState = ref.watch(quizNotifierProvider);
    final isSelect = quizState.currentFlatNumber == number;
    return ElevatedButton(
      onPressed: (quizState.flatRest.toSet().length == 1 &&
                  !quizState.flatRest.toSet().first) ||
              quizState.currentNumber == null ||
              !quizState.flatRest[number]
          ? null
          : () {
              ref.read(quizNotifierProvider.notifier).flatNumberSelect(number);
            },
      style: ButtonStyle(
        textStyle: MaterialStateProperty.all<TextStyle>(
          Montserrat().size12Weihtg600,
        ),
        backgroundColor: MaterialStateProperty.resolveWith<Color>(
            (Set<MaterialState> states) {
          if (states.contains(MaterialState.disabled)) {
            return AppColors.greyButton.withOpacity(0.4);
          } else if (states.contains(MaterialState.pressed)) {
            return AppColors.green;
          }
          return isSelect ? AppColors.green : AppColors.white;
        }),
        foregroundColor: MaterialStateProperty.resolveWith<Color>(
            (Set<MaterialState> states) {
          if (states.contains(MaterialState.disabled)) {
            return AppColors.greyTextButton;
          } else if (states.contains(MaterialState.hovered)) {
            return AppColors.white;
          }
          return isSelect ? AppColors.white : AppColors.blueFlatTextButton;
        }),
        shape: MaterialStateProperty.resolveWith<RoundedRectangleBorder>(
            (Set<MaterialState> states) {
          if (!states.contains(MaterialState.pressed) &&
                  !states.contains(MaterialState.hovered) &&
                  !states.contains(MaterialState.disabled) ||
              isSelect) {
            return RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(6.r),
              side: isSelect
                  ? BorderSide.none
                  : BorderSide(
                      width: 1.h, color: AppColors.blueFlatActiveBorder),
            );
          }
          return RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(6.r),
          );
        }),
        overlayColor: MaterialStateProperty.resolveWith<Color?>(
            (Set<MaterialState> states) {
          if (states.contains(MaterialState.pressed)) {
            return AppColors.blueButton;
          } else if (states.contains(MaterialState.hovered)) {
            return AppColors.pink;
          }
          return null;
        }),
        padding: MaterialStateProperty.all<EdgeInsetsGeometry>(EdgeInsets.zero),
        elevation: MaterialStateProperty.all<double>(0),
        shadowColor: MaterialStateProperty.resolveWith<Color?>(
            (Set<MaterialState> states) {
          if (states.contains(MaterialState.hovered) ||
              states.contains(MaterialState.pressed)) {
            return AppColors.sea;
          }
          return null;
        }),
      ),
      child: Text((number + 1).toString()),
    );
  }
}
