import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_svg/svg.dart';

import '../../../common/images.dart';
import '../../../common/theme/app_colors.dart';
import '../../../common/theme/app_text_style.dart';
import '../../../domain/models/present.dart';
import '../../../domain/models/win_string.dart';

class LastWin extends StatelessWidget {
  const LastWin({
    super.key,
    required this.win,
  });
  final WinString win;

  Widget icon() {
    if (win.present == null) {
      return const Icon(
        Icons.question_mark,
        color: AppColors.white,
      );
    }
    if (win.present == Present.avto.name) {
      return SvgPicture.asset(
        AppIcons.avtoSmall,
        width: 22.w,
        height: 12.h,
      );
    } else if (win.present == Present.moto.name) {
      return SvgPicture.asset(
        AppIcons.motoSmall,
        width: 20.w,
        height: 12.5.h,
      );
    } else if (win.present!.contains(Present.flat.name)) {
      return SvgPicture.asset(
        AppIcons.flatSmall,
        width: 14.w,
        height: 13.5.h,
      );
    } else {
      return const Icon(Icons.question_mark);
    }
  }

  @override
  Widget build(BuildContext context) {
    return win.present != null
        ? Container(
            margin: EdgeInsets.only(right: 6.w),
            alignment: Alignment.center,
            padding: EdgeInsets.all(6.w),
            decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(6.r),
                color: AppColors.white.withOpacity(0.2),
                border: Border.all(width: 0.3.w, color: AppColors.white)),
            child: Row(
              children: [
                Text(
                  win.participant,
                  style: Sans().size18Weihtg500,
                ),
                SizedBox(width: 4.w),
                icon(),
              ],
            ),
          )
        : const SizedBox();
  }
}
