import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../../../common/theme/app_text_style.dart';
import '../../../domain/models/win_string.dart';
import '../../controllers/quiz_notifier.dart';
import 'last_win.dart';

class LastWinsWidget extends ConsumerStatefulWidget {
  const LastWinsWidget({
    super.key,
  });

  @override
  ConsumerState<LastWinsWidget> createState() => _LastWinsWidgetState();
}

class _LastWinsWidgetState extends ConsumerState<LastWinsWidget> {
  final GlobalKey<AnimatedListState> _listKey = GlobalKey<AnimatedListState>();
  late List<WinString> _items;

  void _addItem(WinString newItem) {
    final newIndex = _items.length;
    setState(() {
      _items.add(newItem);
    });
    _listKey.currentState!
        .insertItem(newIndex, duration: const Duration(milliseconds: 800));

    if (_items.length > 5) {
      _removeItem(0);
    }
  }

  void _removeItem(int index) {
    final removedItem = _items[index];

    setState(() {
      _items.removeAt(index);
    });

    _listKey.currentState!.removeItem(
        index,
        (context, animation) => SlideTransition(
              position: Tween<Offset>(
                begin: const Offset(0.1, 0),
                end: const Offset(0, 0),
              ).animate(animation),
              child: buildItem(removedItem, animation),
            ),
        duration: const Duration(milliseconds: 500));
  }

  Widget buildItem(WinString item, Animation<double> animation) {
    return FadeTransition(
      opacity: animation,
      child: LastWin(win: item),
    );
  }

  @override
  void initState() {
    super.initState();
    _items = List.from(ref.read(quizNotifierProvider).lastWins);
  }

  @override
  Widget build(BuildContext context) {
    ScreenUtil.init(context, designSize: const Size(1280, 720));
    ref.listen(quizNotifierProvider, (previous, next) {
      if (!listEquals(previous?.lastWins ?? [], next.lastWins)) {
        _addItem(next.lastWins.last);
      }
    });
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisSize: MainAxisSize.min,
      children: [
        SizedBox(height: 34.h),
        Text(
          'Номера последних 5 обладателей подарков:',
          style: Montserrat().size14Weihtg500.copyWith(
                fontWeight: FontWeight.w600,
              ),
        ),
        SizedBox(height: 16.h),
        SizedBox(
          height: 34.h,
          child: AnimatedList(
            key: _listKey,
            initialItemCount: _items.length,
            scrollDirection: Axis.horizontal,
            shrinkWrap: true,
            physics: const NeverScrollableScrollPhysics(),
            reverse: true,
            itemBuilder: (context, index, animation) =>
                buildItem(_items[index], animation),
          ),
        ),
      ],
    );
  }
}
