import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../../../common/theme/app_colors.dart';
import '../../../common/theme/app_text_style.dart';
import '../../../domain/models/app_tabs.dart';
import '../../../domain/models/present.dart';
import '../../common_widgets/current_time.dart';
import '../../common_widgets/elev_button.dart';
import '../../common_widgets/gradient_border.dart';
import '../../controllers/app_state_notifier.dart';
import '../../controllers/quiz_notifier.dart';
import 'animated_count.dart';

class ParticipantView extends ConsumerWidget {
  const ParticipantView({super.key});

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    ScreenUtil.init(context, designSize: const Size(1280, 720));
    final quizState = ref.watch(quizNotifierProvider);
    final bool needNext =
        ref.read(quizNotifierProvider.notifier).presentRest == 1 &&
            quizState.currentPresent != null;
    return Container(
      width: 393.w,
      padding: EdgeInsets.symmetric(horizontal: 41.w),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(16.r),
        border: gradientBorder(),
        color: AppColors.white.withOpacity(0.3),
      ),
      child: Column(
        children: [
          SizedBox(height: 40.h),
          Text(
            '№ участника',
            style: Montserrat().size20Weihtg600.copyWith(fontSize: 28.sp),
          ),
          SizedBox(height: 35.h),
          Container(
            padding: EdgeInsets.symmetric(horizontal: 16.w, vertical: 9.h),
            alignment: Alignment.center,
            decoration: BoxDecoration(
              color: AppColors.white.withOpacity(0.2),
              borderRadius: BorderRadius.circular(20.r),
              border: Border.all(color: AppColors.white, width: 1.4.h),
            ),
            child: AnimatedCount(
                count: int.tryParse(quizState.currentNumber ?? 'null')),
          ),
          SizedBox(height: 36.h),
          Row(
            children: [
              Expanded(
                child: ElevButton(
                    callback: needNext
                        ? () {
                            ref
                                .read(quizNotifierProvider.notifier)
                                .setPresentPartic();
                            ref
                                .read(appStateNotifierProvider.notifier)
                                .changeTab(AppTabs.phones);
                          }
                        : ((quizState.currentPresent == null) ||
                                    (quizState.currentPresent == Present.flat &&
                                        quizState.currentFlatNumber == null)) &&
                                quizState.currentNumber != null
                            ? null
                            : () {
                                ref
                                    .read(quizNotifierProvider.notifier)
                                    .getNumber();
                              },
                    child: Text(needNext ? 'Завершить этап' : 'Выбрать номер')),
              ),
            ],
          ),
          SizedBox(height: 32.h),
          const CurrentTime(isBig: true),
        ],
      ),
    );
  }
}
