import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_svg/flutter_svg.dart';

import '../../../common/images.dart';
import '../../../common/theme/app_colors.dart';
import '../../../common/theme/app_text_style.dart';
import '../../../common/utils.dart';
import '../../../domain/models/app_tabs.dart';
import '../../common_widgets/current_time.dart';
import '../../common_widgets/elev_button.dart';
import '../../common_widgets/gradient_border.dart';
import '../../controllers/app_state_notifier.dart';
import '../../controllers/global.dart';

class SelectPhonesView extends ConsumerWidget {
  const SelectPhonesView({
    super.key,
    required this.startCallBack,
  });
  final Function() startCallBack;

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    ScreenUtil.init(context, designSize: const Size(1280, 720));
    final globalState = ref.watch(globalProvider);
    final start = globalState.currentPhone == 0;
    final isLoading =
        !start && globalState.currentPhone < globalState.phoneCount;
    final phoneCount = ref.read(appStateNotifierProvider).phoneCount;
    return Container(
      width: 393.w,
      height: 424.h,
      padding: EdgeInsets.symmetric(horizontal: 41.w),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(16.r),
        border: gradientBorder(),
        color: AppColors.white.withOpacity(0.3),
      ),
      child: Column(
        children: [
          SizedBox(height: 40.h),
          RichText(
            textAlign: TextAlign.center,
            text: TextSpan(
              style: Montserrat().size96Weihtg600,
              text: phoneCount.toString(),
              children: [
                TextSpan(
                  text:
                      '\n${getWordOrg(phoneCount, 'смартфон', 'смартфона', 'смартфонов')}',
                  style: Montserrat()
                      .size20Weihtg600
                      .copyWith(fontSize: 40.sp, height: 0.7),
                ),
              ],
            ),
          ),
          SizedBox(height: 36.h),
          isLoading
              ? Container(
                  margin: EdgeInsets.only(left: 24.w),
                  width: 288.w,
                  child: Text(
                    'Идет выбор обладателей смартфонов...',
                    style: Montserrat().size20Weihtg600,
                  ),
                )
              : Row(
                  children: [
                    Expanded(
                      child: start
                          ? ElevButton(
                              callback: startCallBack,
                              child: const Text('Выбрать номера'))
                          : ElevButton(
                              horizontalPadding: 25,
                              callback: () {
                                ref
                                    .read(appStateNotifierProvider.notifier)
                                    .changeTab(AppTabs.result);
                              },
                              child: Row(
                                mainAxisAlignment: MainAxisAlignment.center,
                                children: [
                                  const Text('Перейти к протоколу'),
                                  SizedBox(width: 12.w),
                                  SvgPicture.asset(
                                    AppIcons.forward,
                                    width: 17.w,
                                    height: 22.w,
                                  ),
                                ],
                              )),
                    ),
                  ],
                ),
          SizedBox(height: 32.h),
          const CurrentTime(isBig: true),
        ],
      ),
    );
  }
}
