// ignore_for_file: use_build_context_synchronously

import 'dart:io';
import 'dart:math';

import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_svg/flutter_svg.dart';

import '../../common/file_names.dart';
import '../../common/images.dart';
import '../../common/logger.dart';
import '../../common/service_locator.dart';
import '../../common/theme/app_colors.dart';
import '../../common/theme/app_text_style.dart';
import '../../domain/models/present.dart';
import '../common_widgets/elev_button.dart';
import '../settings_view/widgets/footer_settings.dart';
import 'widgets/result_present_container.dart';

class ResultScreen extends StatefulWidget {
  const ResultScreen({super.key});

  @override
  State<ResultScreen> createState() => _ResultScreenState();
}

class _ResultScreenState extends State<ResultScreen> {
  String? hashResult;

  SnackBar customSnack(String text, Color color) => SnackBar(
        content: Text(text, style: Montserrat().size18Weihtg600),
        backgroundColor: color,
        behavior: SnackBarBehavior.floating,
        dismissDirection: DismissDirection.none,
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.all(Radius.circular(16.r)),
        ),
        padding: EdgeInsets.symmetric(horizontal: 24.w, vertical: 20.h),
        margin: EdgeInsets.only(
            bottom: MediaQuery.sizeOf(context).height - 156.h,
            left: MediaQuery.sizeOf(context).width * 0.25,
            right: MediaQuery.sizeOf(context).width * 0.25),
      );

  Future<void> getResult(BuildContext context) async {
    String? selectedFolder = await FilePicker.platform.getDirectoryPath();

    if (selectedFolder != null) {
      debugPrint('Выбранная папка: $selectedFolder');

      try {
        if (!File(FileNames.devResultPath).existsSync()) {
          ServiceLocator.instance.resultUtils.saveResult(selectedFolder);
        } else {
          ServiceLocator.instance.resultUtils.copyResult(selectedFolder);
        }

        if (hashResult == null || hashResult!.isEmpty) {
          hashResult = await ServiceLocator.instance.hashUtils
              .getHashFromFile(FileNames.devResultPath);
        }
        setState(() {});
        SnackBar snackBar = customSnack(
            'Файл успешно сохранён в $selectedFolder', AppColors.green);
        ScaffoldMessenger.of(context).showSnackBar(snackBar);
      } catch (e) {
        SnackBar snackBar = customSnack(e.toString(), AppColors.pink);
        ScaffoldMessenger.of(context).showSnackBar(snackBar);
      }
    } else {
      debugPrint('Папка не выбрана.');
      SnackBar snackBar = customSnack('Папка не выбрана', AppColors.pink);
      ScaffoldMessenger.of(context).showSnackBar(snackBar);
    }
  }

  @override
  void initState() {
    super.initState();
    try {
      ServiceLocator.instance.hashUtils
          .getHashFromFile(FileNames.devResultPath)
          .then((value) => setState(() {
                hashResult = value;
              }));
    } catch (e) {
      logger.e(e);
    }
  }

  @override
  Widget build(BuildContext context) {
    ScreenUtil.init(context, designSize: const Size(1280, 720));
    return Column(
      children: [
        SizedBox(height: 12.h),
        Text(
          'Выбор обладателей ценных подарков\nвикторины «ОПОРНЫЙ КРАЙ» завершен'
              .toUpperCase(),
          style: Montserrat().size38Weihtg700.copyWith(fontSize: 24.sp),
          textAlign: TextAlign.center,
        ),
        SizedBox(height: 18.h),
        SizedBox(
          height: 330.h,
          width: 936.w,
          child: ListView.separated(
              scrollDirection: Axis.horizontal,
              shrinkWrap: true,
              physics: const NeverScrollableScrollPhysics(),
              itemBuilder: (context, index) =>
                  ResultPresentContainer(present: Present.values[index]),
              separatorBuilder: (context, index) => SizedBox(width: 16.w),
              itemCount: Present.values.length),
        ),
        SizedBox(height: 18.h),
        Container(
          width: 936.w,
          padding: EdgeInsets.symmetric(
            vertical: 14.h,
            horizontal: 18.w,
          ),
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(16.r),
            color: AppColors.white.withOpacity(0.3),
          ),
          child: Row(
            children: [
              ElevButton(
                  callback: () {
                    getResult(context);
                  },
                  child: Row(
                    children: [
                      const Text('Скачать протокол'),
                      SizedBox(width: 12.w),
                      Transform.rotate(
                        angle: pi / 2,
                        child: SvgPicture.asset(
                          AppIcons.forward,
                          width: 17.w,
                          height: 22.w,
                        ),
                      ),
                    ],
                  )),
              SizedBox(width: 29.w),
              if (hashResult != null)
                Text(
                  'MD5 протокола: $hashResult',
                  style: Montserrat().size20Weihtg400.copyWith(fontSize: 16.sp),
                ),
            ],
          ),
        ),
        const Spacer(),
        const FooterSettings(),
      ],
    );
  }
}
