import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_svg/flutter_svg.dart';

import '../../../common/images.dart';
import '../../../common/theme/app_colors.dart';
import '../../../common/theme/app_text_style.dart';
import '../../../domain/models/present.dart';

class ResultPresentContainer extends StatelessWidget {
  const ResultPresentContainer({
    super.key,
    required this.present,
  });

  final Present present;

  Widget get image => switch (present) {
        Present.avto => SvgPicture.asset(
            AppIcons.avto,
            width: 120.w,
            height: 149.h,
          ),
        Present.flat => SvgPicture.asset(
            AppIcons.flat,
            width: 100.w,
            height: 120.h,
          ),
        Present.moto => SvgPicture.asset(
            AppIcons.moto,
            width: 171.w,
            height: 160.h,
          ),
        Present.phone => SvgPicture.asset(
            AppImages.phone,
            width: 94.w,
            height: 149.h,
          ),
      };

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.all(5.w),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(16.h),
        border:
            Border.all(color: AppColors.blueResultPresentBorder, width: 1.h),
      ),
      height: 330.h,
      width: 222.w,
      child: Container(
        padding: EdgeInsets.only(bottom: 20.h, top: 5.h),
        decoration: BoxDecoration(
          color: AppColors.white,
          borderRadius: BorderRadius.circular(16.r),
          border: Border.all(color: AppColors.green, width: 2.h),
        ),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.spaceEvenly,
          children: [
            Stack(
              alignment: Alignment.center,
              clipBehavior: Clip.none,
              children: [
                SvgPicture.asset(
                  AppBackgrounds.pointsSvg,
                  width: 170.w,
                  height: 170.w,
                ),
                image,
              ],
            ),
            Text(
              present.name,
              style: Montserrat().size24Weihtg600Blue,
            ),
            SvgPicture.asset(
              AppIcons.done,
              // ignore: deprecated_member_use
              color: AppColors.green,
              width: 40.w,
              height: 40.w,
            )
          ],
        ),
      ),
    );
  }
}
