import 'dart:io';

import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:smooth_page_indicator/smooth_page_indicator.dart';

import '../../common/file_names.dart';
import '../../common/theme/app_colors.dart';
import '../../common/theme/app_text_style.dart';
import '../../domain/models/app_tabs.dart';
import '../common_widgets/gradient_border.dart';
import '../controllers/app_state_notifier.dart';
import '../controllers/global.dart';
import '../controllers/participants_list_notifier.dart';
import 'widgets/footer_settings.dart';
import 'widgets/load_file.dart';
import 'widgets/settings_count.dart';
import 'widgets/success_load.dart';

class SettingsScreen extends ConsumerStatefulWidget {
  const SettingsScreen({super.key});

  @override
  ConsumerState<SettingsScreen> createState() => _SettingsScreenState();
}

class _SettingsScreenState extends ConsumerState<SettingsScreen> {
  late final PageController controller;

  int initPage = 0;

  Future<void> selectFile(BuildContext context, WidgetRef ref) async {
    FilePickerResult? result = await FilePicker.platform.pickFiles(
      type: FileType.custom,
      allowedExtensions: ['csv'],
    );

    if (result != null) {
      File(result.files.single.path!).copySync(FileNames.origPartCopyPath);
      var lines = await File(FileNames.origPartCopyPath).readAsLines();
      ref.read(participantsListNotifierProvider.notifier).getPart(lines);
      controller.nextPage(
          duration: const Duration(milliseconds: 300), curve: Curves.easeIn);
    } else {
      debugPrint('Файл не выбран');
    }
  }

  void goToSettingsCount() {
    controller.nextPage(
        duration: const Duration(milliseconds: 300), curve: Curves.easeIn);
    ref.read(globalProvider.notifier).startCheckCount();
  }

  void goToQuiz() {
    ref.read(appStateNotifierProvider.notifier).changeTab(AppTabs.quiz);
  }

  @override
  void initState() {
    super.initState();

    if (ref.read(globalProvider).startCheckCount) {
      initPage = 2;
    } else if (ref.read(globalProvider).participantsLoaded) {
      initPage = 1;
    }

    controller = PageController(initialPage: initPage);
  }

  @override
  Widget build(BuildContext context) {
    ScreenUtil.init(context, designSize: const Size(1280, 720));
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        Text(
          'Приветствуем вас на Викторине'.toUpperCase(),
          style: Montserrat().size38Weihtg700,
        ),
        Text(
          '«Опорный край»'.toUpperCase(),
          style: Montserrat().size38Weihtg700.copyWith(fontSize: 50.sp),
        ),
        Expanded(
          child: Container(
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(16.r),
              color: AppColors.white.withOpacity(0.35),
              border: gradientBorder(),
            ),
            margin: EdgeInsets.only(top: 33.h, bottom: 37.h),
            width: 748.w,
            padding: EdgeInsets.only(
                top: 36.h, bottom: 24.h, right: 34.w, left: 34.w),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                Expanded(
                  child: SizedBox(
                    height: MediaQuery.sizeOf(context).height / 3,
                    child: PageView(
                      controller: controller,
                      children: [
                        LoadFile(callback: () => selectFile(context, ref)),
                        SuccessLoad(callback: goToSettingsCount),
                        SettingsCount(callback: goToQuiz),
                      ],
                    ),
                  ),
                ),
                Align(
                  alignment: Alignment.bottomRight,
                  child: SmoothPageIndicator(
                    controller: controller,
                    count: 3,
                    effect: WormEffect(
                      spacing: 4.w,
                      activeDotColor: AppColors.pink,
                      dotColor: AppColors.white,
                      dotHeight: 8.w,
                      dotWidth: 8.w,
                    ),
                  ),
                ),
              ],
            ),
          ),
        ),
        const FooterSettings(),
      ],
    );
  }
}
