import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../../../common/theme/app_colors.dart';
import '../../../common/theme/app_text_style.dart';
import '../../../domain/models/present.dart';
import '../../controllers/app_state_notifier.dart';

class SettingsRow extends ConsumerStatefulWidget {
  const SettingsRow({super.key, required this.present});
  final Present present;

  @override
  ConsumerState<SettingsRow> createState() => _SettingsRowNewState();
}

class _SettingsRowNewState extends ConsumerState<SettingsRow> {
  final TextEditingController controller = TextEditingController();

  var inputDecoration = InputDecoration(
    isDense: true,
    contentPadding: const EdgeInsets.symmetric(vertical: 10),
    enabledBorder: OutlineInputBorder(
      borderRadius: BorderRadius.circular(8.r),
      borderSide: const BorderSide(color: Colors.transparent),
    ),
    focusedBorder: OutlineInputBorder(
      borderRadius: BorderRadius.circular(8.r),
      borderSide:
          BorderSide(color: AppColors.white.withOpacity(0.85), width: 1.h),
    ),
    border: OutlineInputBorder(
      borderRadius: BorderRadius.circular(8.r),
      borderSide: const BorderSide(color: Colors.transparent),
    ),
  );

  @override
  void initState() {
    super.initState();

    controller.text = switch (widget.present) {
      Present.flat => ref.read(appStateNotifierProvider).flatCount.toString(),
      Present.avto => ref.read(appStateNotifierProvider).avtoCount.toString(),
      Present.moto => ref.read(appStateNotifierProvider).motoCount.toString(),
      Present.phone => ref.read(appStateNotifierProvider).phoneCount.toString(),
    };
  }

  @override
  Widget build(BuildContext context) {
    ScreenUtil.init(context, designSize: const Size(1280, 720));
    return Container(
      height: 56.h,
      width: 300.h,
      padding: EdgeInsets.only(
        top: 8.h,
        bottom: 8.h,
        right: 9.w,
        left: 26.w,
      ),
      decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(16.h),
          color: AppColors.white.withOpacity(0.3)),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Text(
            widget.present.name,
            style: Montserrat().size18Weihtg600,
          ),
          SizedBox(
            width: 78.w,
            child: Focus(
              onFocusChange: (value) {
                if (!value) {
                  ref
                      .read(appStateNotifierProvider.notifier)
                      .changePresentCount(widget.present, controller.text);
                }
              },
              child: TextFormField(
                controller: controller,
                inputFormatters: [FilteringTextInputFormatter.digitsOnly],
                textAlign: TextAlign.center,
                textAlignVertical: TextAlignVertical.center,
                style: Montserrat().size20Weihtg600,
                cursorColor: AppColors.white,
                decoration: inputDecoration,
              ),
            ),
          ),
        ],
      ),
    );
  }
}
